import pickle
import configparser
from pathlib import Path
import os

# INDEXED TAG OF TRAINED CORPUS
def get_POS_TAGS_index():
    
    

    # postagsindex_pkl_filepath = config['PATHS']['postagsindex_pkl_filepath']
    # postagsindex_pkl_filepath = config.get('postagsindex_pkl_filepath')
    # postagsindex_pkl_filepath = Path('models/tagindex_model.pkl')
    postagsindex_pkl_filepath = os.path.join(os.path.dirname(__file__), 'models', 'tagindex_model.pkl')

    with open(postagsindex_pkl_filepath, "rb") as f:
        tagindex_model = pickle.load(f)
        
    return tagindex_model

pos_tags = get_POS_TAGS_index()
get_POS_TAGS_index()


import pickle
import configparser
import os
from pathlib import Path

# VOCABULARY OF THE MODEL
def get_VOCAB_model():
    # with open(vocabs_pkl_filepath, "rb") as f:
    #     vocab_model = pickle.load(f)
    
    # file = Path('config.ini')
    # config = configparser.ConfigParser()
    # config.read(file)
    
    # vocabs_pkl_filepath = Path('models/vocab_model2.pkl')
    # vocabs_pkl_filepath = config['PATHS']['vocabs_pkl_filepath']
    # vocabs_pkl_filepath = config.get('PATHS', 'vocabs_pkl_filepath')

    # with open(vocabs_pkl_filepath, "rb") as f:
    #     vocab_model = pickle.load(f)
    
    data_path = os.path.join(os.path.dirname(__file__), 'models', 'vocab_model2.pkl')

    with open(data_path, 'rb') as data_file:
        vocab_model = pickle.load(data_file)
    
    return vocab_model

get_VOCAB_model()


import pandas as pd
import configparser
from pathlib import Path
import os

# GET CORPUS
def cebuano_corpus():
    # ceb_corpus = pd.read_csv(corpus_csv_filepath)
    
    # file = Path('config.ini')
    # config = configparser.ConfigParser()
    # config.read(file)

    # corpus_csv_filepath = config['PATHS']['corpus_csv_filepath']
    # corpus_csv_filepath = config.get('PATHS', 'corpus_csv_filepath')
    # corpus_csv_filepath = Path('Datasets/annotatedtestxt.csv')
    corpus_csv_filepath = os.path.join(os.path.dirname(__file__), 'models', 'annotatedtestxt.csv')

    corpus_csv_filepath = pd.read_csv(corpus_csv_filepath)
    
    return corpus_csv_filepath

cebuano_corpus()


import os
import pickle

data_path = os.path.join(os.path.dirname(__file__), 'models', 'vocab_model2.pkl')

with open(data_path, 'rb') as data_file:
    vocab_model = pickle.load(data_file)
    
print(vocab_model)